@@ -127,9 +127,11 @@ class BaseRecipe(BaseSlapRecipe):
         self.substituteTemplate(pkg_resources.resource_filename(__name__,
           'template/apache.in'), apache_config))
     self.path_list.append(config_file)
+    php_ini = pkg_resources.resource_filename(__name__, 'template/php.ini.in')
+    if self.options.has_key('php_ini'):
+      php_ini = os.path.join(self.options['php_ini'], 'php.ini.in')
     self.path_list.append(self.createConfigurationFile('php.ini',
-        self.substituteTemplate(pkg_resources.resource_filename(__name__,
-          'template/php.ini.in'), dict(tmp_directory=self.tmp_directory))))
+        self.substituteTemplate(php_ini, dict(tmp_directory=self.tmp_directory))))
     self.path_list.extend(zc.buildout.easy_install.scripts([(
       'httpd',
         __name__ + '.apache', 'runApache')], self.ws,
@@ -153,23 +155,23 @@ class BaseRecipe(BaseSlapRecipe):
     destination = os.path.join(path, file)
     open(destination, 'w').write(open(template, 'r').read() % d)
 
-  def configureInstallation(self, document_root, mysql_conf, url):
+  def configureInstallation(self, document_root, url, mysql_conf):
     """Start process which can launch python scripts, move or remove files or 
     directories when installing software.
     """
     if not self.options.has_key('delete') and not self.options.has_key('rename') and not\
         self.options.has_key('chmod') and not self.options.has_key('script'):
-      return
+      return ""
     delete = []
     chmod = []
     data = []
     rename = []
     rename_list = ""
-    argument = [self.options['lampconfigure_directory'].strip()]
+    argument = [self.options['lampconfigure_directory'].strip(),
+                             "-H", mysql_conf['mysql_host'], "-P", mysql_conf['mysql_port'],
+                             "-p", mysql_conf['mysql_password'], "-u", mysql_conf['mysql_user']]
     if not self.options.has_key('file_token'):
       argument = argument + ["-d", mysql_conf['mysql_database'],
-                             "-H", mysql_conf['mysql_host'], "-P", mysql_conf['mysql_port'],
-                             "-p", mysql_conf['mysql_password'], "-u", mysql_conf['mysql_user'],
                              "--table", self.options['table_name'].strip(), "--cond",
                              self.options['constraint'].strip()]
     else:
@@ -193,9 +195,9 @@ class BaseRecipe(BaseSlapRecipe):
         if self.options.has_key('rename_chmod'):
           cmd += ["--chmod", self.options['rename_chmod'].strip()]
         rename.append(cmd + [fname[0].strip(), fname[1].strip()])
-        rename_list += fname[0] + "=>" + fname[1] + " "
+        rename_list += fname[0] + " to " + fname[1] + " "
     if self.options.has_key('chmod'):
-      chmod = ["chmod ", self.options['mode'].strip()]
+      chmod = ["chmod", self.options['mode'].strip()]
       for fname in self.options['chmod'].split(','):
         chmod.append(fname.strip())
     if self.options.has_key('script') and \
@@ -225,12 +227,14 @@ class Simple(BaseRecipe):
     self.createHtdocs(self.options['source'].strip(), document_root)
     mysql_conf = self.installMysqlServer()
     url = self.installApache(document_root)
-    renamed = self.configureInstallation(document_root, mysql_conf, url)
-    self.setConnectionDict(dict(
-      url=url,
-      rename=renamed,
+    renamed = self.configureInstallation(document_root, url, mysql_conf)
+    connectionDict = dict(
+      url=url,      
       **mysql_conf
-    ))
+    )
+    if not renamed == "":
+      connectionDict['rename'] = renamed
+    self.setConnectionDict(connectionDict)
     if self.options.has_key('template') and self.options.has_key('configuration'):
       self.createConfiguration(self.options['template'], document_root,
           self.options['configuration'], mysql_conf)
